<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="java"
	exclude-result-prefixes="fo"
>

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" />

	<xsl:include href="template://Barcode_Template.xsl" />
	<xsl:include href="template://Sticker_Template_Common_Fields.xsl" />

	<xsl:include href="customVariables://userDefinedInFile_print.properties" />


	<!-- ============================== -->
	<!-- Template: Single Sticker (A6) -->
	<!-- ============================== -->

	<xsl:template match="sticker">
		<xsl:choose>
			<xsl:when test="/report/demo = 'true'">
				<fo:block background-image="url('image://FOP_DEMO')" background-position="0,0" background-repeat="repeat" background-color="white" padding="3mm">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block padding="3mm">
					<xsl:call-template name="main_table"></xsl:call-template>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="main_table">
		<fo:table width="100%">
			<fo:table-column column-width="10mm" />
			<fo:table-column column-width="83.5mm" />
			<fo:table-column column-width="38mm" />
			<fo:table-body>
				<fo:table-row>
					<xsl:call-template name="table_cell_barcode_small_labels_vertical"></xsl:call-template>
					<fo:table-cell>
						<!-- Central column -->
						<!-- Block margin=0 is important, otherwise block would become bigger than table cell -->
						<fo:block padding="1mm" font-style="normal" margin="0">
							<fo:table width="100%">
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell height="80mm">
											<!-- Licensee logo -->
											<fo:block margin-bottom="0.5mm">
												<xsl:call-template name="licensee_logo"></xsl:call-template>
											</fo:block>
											<!-- Sender box -->
											<xsl:call-template name="sender_box">
												<xsl:with-param name="print_phones" select="'true'" />
												<xsl:with-param name="scale_factor" select="0.9" />
											</xsl:call-template>
											<!-- Barcode postal code (sender) -->
											<fo:block padding="0.1mm" text-align="center">
												<xsl:call-template name="barcode">
													<xsl:with-param name="codeType" select="'postalCode'" />
													<xsl:with-param name="message" select="sender/postalCode" />
												</xsl:call-template>
											</fo:block>
											<!-- Receiver box -->
											<xsl:call-template name="receiver_box"></xsl:call-template>
											<!-- Barcode multifunctional code - receiver ZIP code instead for B2C -->
											<fo:block padding="0.1mm" text-align="center">
												<xsl:call-template name="barcode">
													<xsl:with-param name="codeType" select="'postalCode'" />
													<xsl:with-param name="message" select="receiver/postalCode" />
													<!-- <xsl:with-param name="codeType" select="'multifunctional'" /> <xsl:with-param name="message" select="multifunctionalCode" /> -->
												</xsl:call-template>
											</fo:block>
											<!-- Contact persons -->
											<xsl:call-template name="contact_persons"></xsl:call-template>
											<!-- Delivery remark -->
											<fo:block padding="0.1mm" overflow="hidden">
												<fo:table width="100%">
													<fo:table-body>
														<fo:table-row>
															<fo:table-cell>
																<fo:block font-size="{$stickerFldDelyRemarkFontSize}" font-style="normal" font-weight="{$stickerFldDelyRemarkFontWeight}" wrap-option="wrap">
																	<fo:inline font-weight="bold">
																		<xsl:value-of select="/report/lblDeliveryRemark" />
																		<xsl:text>: </xsl:text>
																	</fo:inline>
																	<xsl:call-template name="forcedWrapText">
																		<xsl:with-param name="data" select="deliveryRemark" />
																	</xsl:call-template>
																</fo:block>
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>

										</fo:table-cell>

									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>

					<!-- Right column -->

					<fo:table-cell margin="0" margin-left="3.5mm" padding="0">
						<fo:block padding="0" margin="0">
							<fo:table width="100%">
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell height="18mm" padding="0" margin="0">
											<fo:block padding="0" margin="0" text-align="center">
												<xsl:call-template name="barcode">
													<xsl:with-param name="message" select="substring(trackingCode, 7, 8)" />
													<xsl:with-param name="codeType" select="'trackingCode'" />
												</xsl:call-template>
											</fo:block>
											<fo:block padding="0" padding-top="-1mm" margin="0" font-size="4mm" text-align="center">
												<xsl:value-of select="substring(trackingCode, 7, 8)" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

									<fo:table-row>
										<!-- Reference box and services will be stored in additional table with fixed height as, reference size may vary as well as services list -->
										<fo:table-cell height="36mm" margin="0" padding="0">
											<fo:block>
												<fo:table width="100%">
													<fo:table-body>
														<!-- Reference box -->
														<fo:table-row>
															<fo:table-cell>
																<xsl:call-template name="date_and_reference_nr">
																	<xsl:with-param name="print_date" select="'true'" />
																	<xsl:with-param name="print_weight" select="'true'" />
																	<xsl:with-param name="print_reference_numbers" select="'true'" />
																</xsl:call-template>
															</fo:table-cell>
														</fo:table-row>

														<!-- Services - no services listed for B2C -->
														<fo:table-row>
															<fo:table-cell>
																<fo:block>
																	<xsl:text> </xsl:text>
																</fo:block>
																<!-- <fo:block margin-top="2mm" margin-bottom="1mm"> <fo:table width="100%"> <fo:table-body> <fo:table-row> <fo:table-cell> <fo:block font-size="2mm"> <xsl:value-of 
																	select="/report/lblServices" /> </fo:block> </fo:table-cell> </fo:table-row> <fo:table-row> <fo:table-cell> <fo:block font-size="3.5mm" font-weight="bold" font-style="normal" margin-top="0.5mm"> 
																	<xsl:value-of select="servicesDescriptor" /> </fo:block> </fo:table-cell> </fo:table-row> </fo:table-body> </fo:table> </fo:block> -->
															</fo:table-cell>
														</fo:table-row>
													</fo:table-body>
												</fo:table>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

									<!-- No routing info for B2C -->
									<fo:table-row>
										<fo:table-cell>
											<fo:block margin="0" padding="0">
												<xsl:text> </xsl:text>
											</fo:block>
										</fo:table-cell>
									</fo:table-row>

								</fo:table-body>
							</fo:table>
						</fo:block>

					</fo:table-cell>
				</fo:table-row>

				<!-- Footer -->
				<fo:table-row>
					<fo:table-cell>
						<fo:block></fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block font-size="2mm">
							<xsl:value-of select="/report/licenseeInfo/shortDescription" />
						</fo:block>
						<fo:block font-size="1.5mm">
							<xsl:value-of select="/report/expeditInfo/name" />
						</fo:block>
					</fo:table-cell>
					<fo:table-cell margin="0">
						<fo:block font-size="2.7mm" text-align="right" padding-right="4mm">
							<!-- <xsl:text> </xsl:text> -->
							<xsl:value-of select="formattedPacketNumber" />
						</fo:block>
					</fo:table-cell>
				</fo:table-row>

			</fo:table-body>
		</fo:table>
	</xsl:template>

</xsl:stylesheet>

