<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="java"
	exclude-result-prefixes="fo"
>

	<xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" />

	<!-- ========================================= -->
	<!-- Sticker template: Common fields templates -->
	<!-- ========================================= -->

	<!-- ============================== -->
	<!-- Common template parts -->
	<!-- ============================== -->

	<xsl:template name="licensee_logo">
		<fo:table width="100%">
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<xsl:choose>
							<xsl:when test="/report/printLicenseeLogoOnLabel = 'true'">
								<fo:block>
									<fo:inline padding-right="1mm">
										<fo:external-graphic height="8mm" content-width="scale-to-fit" src='{concat("url(&apos;crimage://", /report/licenseeInfo/logoPathLabel, "&apos;)")}' />
									</fo:inline>
								</fo:block>
							</xsl:when>
							<xsl:otherwise>
								<fo:block font-size="3.5mm" font-weight="bold" font-style="italic">
									<xsl:value-of select="/report/licenseeInfo/name" />
								</fo:block>
							</xsl:otherwise>
						</xsl:choose>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block>
							<fo:table width="100%">
								<fo:table-body>
									<!-- padding right needed to make tracking bar-code quiet zone 4mm -->
									<fo:table-row>
										<fo:table-cell padding-right="3mm">
											<fo:block font-size="2.5mm" text-align="right">
												<xsl:value-of select="/report/licenseeInfo/phone" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell padding-right="3mm">
											<fo:block font-size="2.5mm" text-align="right" font-style="italic">
												<xsl:value-of select="/report/licenseeInfo/httpAddress" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="receiver_box">
		<xsl:param name="print_phones" select="'true'" />
		<fo:block font-size="3mm" border-style="solid" border-width="thin" padding="1mm" wrap-option="no-wrap" overflow="hidden" margin-bottom="1mm">
			<fo:block font-size="2.1mm" font-style="italic">
				<xsl:value-of select="/report/lblReceiver" />
			</fo:block>
			<xsl:call-template name="_internal_receiver_sender_data">
				<xsl:with-param name="person" select="receiver" />
				<xsl:with-param name="print_phone_numbers" select="$print_phones" />
				<xsl:with-param name="scale_factor" select="1.1" />
			</xsl:call-template>
		</fo:block>
	</xsl:template>

	<xsl:template name="sender_box">
		<xsl:param name="print_phones" select="'true'" />
		<fo:block font-size="3mm" border-style="none" border-width="0" padding="1mm" wrap-option="no-wrap" overflow="hidden">
			<fo:block font-size="2.1mm" font-style="italic">
				<xsl:value-of select="/report/lblSender" />
			</fo:block>
			<xsl:choose>
				<xsl:when test="printSenderLogo = 'true'">
					<fo:block text-align="center">
						<fo:inline>
							<fo:external-graphic width="70mm" height="18mm" content-width="scale-to-fit" content-height="scale-to-fit" src="url('logo://expedit')" />
						</fo:inline>
					</fo:block>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="_internal_receiver_sender_data">
						<xsl:with-param name="person" select="sender" />
						<xsl:with-param name="text_alignment" select="'left'" />
						<xsl:with-param name="print_phone_numbers" select="$print_phones" />
						<xsl:with-param name="scale_factor" select="1.0" />
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</fo:block>
	</xsl:template>

	<xsl:template name="_internal_receiver_sender_data">
		<xsl:param name="person" />
		<xsl:param name="text_alignment" select="'center'" />
		<xsl:param name="print_phone_numbers" select="'true'" />
		<xsl:param name="scale_factor" select="1.0" />
		<xsl:variable name="var_name_font_size" select="concat($scale_factor * 3.2, 'mm')" />
		<xsl:variable name="var_address_font_size" select="concat($scale_factor * 2.8, 'mm')" />
		<fo:block text-align="{$text_alignment}" font-size="{$var_name_font_size}" wrap-option="wrap" font-weight="bold" font-style="normal">
			<xsl:call-template name="forcedWrapText">
				<xsl:with-param name="data" select="$person/name" />
			</xsl:call-template>
			<!-- <xsl:value-of select="$person/name" /> -->
		</fo:block>
		<fo:block text-align="{$text_alignment}" font-size="{$var_address_font_size}" wrap-option="wrap">
			<xsl:call-template name="forcedWrapText">
				<xsl:with-param name="data" select="$person/address" />
			</xsl:call-template>
			<!-- <xsl:value-of select="$person/address" /> -->
		</fo:block>
		<fo:block text-align="{$text_alignment}" font-size="{$var_address_font_size}" wrap-option="wrap">
			<xsl:value-of select="$person/countryCode" />
			<xsl:text> </xsl:text>
			<xsl:value-of select="$person/postalCode" />
			<xsl:text>, </xsl:text>
			<xsl:value-of select="$person/city" />
		</fo:block>
		<xsl:choose>
			<xsl:when test="$print_phone_numbers = 'true'">
				<!-- <fo:block text-align="center" margin-left="0mm" font-size="2.75mm"> <fo:inline padding-right="1mm"> <fo:external-graphic height="2.75mm" content-width="scale-to-fit" src="url('image://FOP_ICON_PHONE')" 
					/> </fo:inline> <xsl:value-of select="$person/phone" /> </fo:block> -->
				<fo:block text-align="left" margin-left="7mm" margin-top="0.25mm" font-size="2.75mm">
					<xsl:text>Tel.: </xsl:text>
					<xsl:value-of select="$person/phoneFix" />
				</fo:block>
				<fo:block text-align="left" margin-left="7mm" font-size="2.75mm">
					<xsl:text>GSM: </xsl:text>
					<xsl:value-of select="$person/phoneGSM" />
				</fo:block>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="contact_persons">
		<fo:block padding="0" padding-top="0.4mm" padding-bottom="0.3mm" wrap-option="no-wrap" overflow="hidden">
			<fo:table width="100%">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-size="2mm">
								<xsl:value-of select="/report/lblReceiver" />
								<xsl:text> - </xsl:text>
								<xsl:value-of select="/report/lblContactPerson" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-size="2mm">
								<xsl:value-of select="/report/lblSender" />
								<xsl:text> - </xsl:text>
								<xsl:value-of select="/report/lblContactPerson" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell>
							<fo:block font-size="2.5mm">
								<xsl:value-of select="receiverContactPerson" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-size="2.5mm">
								<xsl:value-of select="senderContactPerson" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template name="barcode_postal_code_receiver">
		<fo:block padding="0.1mm" text-align="center">
			<xsl:call-template name="barcode">
				<xsl:with-param name="codeType" select="'postalCode'" />
				<xsl:with-param name="message" select="receiver/postalCode" />
			</xsl:call-template>
		</fo:block>
	</xsl:template>

	<xsl:template name="barcode_multifunctional_code">
		<fo:block padding="0.1mm" text-align="center">
			<xsl:call-template name="barcode">
				<xsl:with-param name="codeType" select="'multifunctional'" />
				<xsl:with-param name="message" select="multifunctionalCode" />
			</xsl:call-template>
		</fo:block>
	</xsl:template>

	<xsl:template name="barcode_tracking_code">
		<fo:block padding="0" margin="0" text-align="center">
			<xsl:call-template name="barcode">
				<xsl:with-param name="message" select="trackingCode" />
				<xsl:with-param name="codeType" select="'trackingCode'" />
			</xsl:call-template>
		</fo:block>
		<fo:block padding="0" padding-top="-1mm" padding-left="2mm" margin="0" font-size="4mm" text-align="center">
			<xsl:value-of select="substring(trackingCode, 1, 6)" />
			<xsl:text> </xsl:text>
			<fo:inline font-weight="bold">
				<xsl:value-of select="substring(trackingCode, 7, 8)" />
			</fo:inline>
			<xsl:text> </xsl:text>
			<xsl:value-of select="substring(trackingCode, 15, 2)" />
		</fo:block>
	</xsl:template>

	<xsl:template name="table_cell_barcode_small_labels_vertical">
		<xsl:choose>
			<xsl:when test="printSmallLabels = 'true'">
				<fo:table-cell padding="0.5mm" padding-top="0mm" display-align="center">
					<fo:block>
						<xsl:call-template name="barcode">
							<xsl:with-param name="message" select="trackingCode" />
							<xsl:with-param name="codeType" select="'smallLabel'" />
						</xsl:call-template>
					</fo:block>
					<fo:block font-size="5mm" color="white">
						<xsl:text>I</xsl:text>
					</fo:block>
					<fo:block>
						<xsl:call-template name="barcode">
							<xsl:with-param name="message" select="trackingCode" />
							<xsl:with-param name="codeType" select="'smallLabel'" />
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
			</xsl:when>
			<xsl:otherwise>
				<fo:table-cell padding="1mm" padding-top="1mm">
					<xsl:choose>
						<xsl:when test="string-length(referenceNr1Barcode) = 0">
							<fo:block>
								<xsl:text> </xsl:text>
							</fo:block>
						</xsl:when>
						<xsl:otherwise>
							<fo:block>
								<xsl:call-template name="barcode">
									<xsl:with-param name="codeType" select="'referenceNr1'" />
									<xsl:with-param name="message" select="substring(referenceNr1Barcode, 1, 35)" />
								</xsl:call-template>
							</fo:block>
						</xsl:otherwise>
					</xsl:choose>
				</fo:table-cell>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="date_and_reference_nr">
		<fo:block margin="0" margin-bottom="1mm" padding="0" font-size="2.3mm">
			<fo:table width="100%">
				<fo:table-column column-width="25%" />
				<fo:table-column column-width="35%" />
				<fo:table-column column-width="40%" />
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell padding="0.5mm">
							<fo:block>
								<xsl:value-of select="/report/datum/label" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell padding="0.5mm">
							<fo:block>
								<xsl:value-of select="datum" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell padding="0.5mm" padding-right="0" text-align="right">
							<fo:block>
								<xsl:value-of select="formattedPacketNumber" />
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<!-- <fo:table-row> <fo:table-cell padding="0.5mm"> <fo:block> <xsl:value-of select="/report/weight/label" /> </fo:block> </fo:table-cell> <fo:table-cell padding="0.5mm"> <fo:block> 
						<xsl:value-of select="weight" /> </fo:block> </fo:table-cell> </fo:table-row> -->
					<fo:table-row>
						<fo:table-cell padding="0.5mm" wrap-option="no-wrap" display-align="center">
							<fo:block>
								<xsl:value-of select="/report/lblReferenceNr1Short" />
							</fo:block>
						</fo:table-cell>
						<fo:table-cell padding="0.5mm" number-columns-spanned="2">
							<fo:block wrap-option="wrap">
								<xsl:call-template name="forcedWrapText">
									<xsl:with-param name="data" select="referenceNr1" />
								</xsl:call-template>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template name="services_without_routing_label_barcode">
		<fo:table width="100%">
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block margin-top="2mm" margin-bottom="1mm">
							<fo:table width="100%">
								<fo:table-body>
									<fo:table-row>
										<fo:table-cell>
											<fo:block font-size="2mm">
												<xsl:value-of select="/report/lblServices" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
									<fo:table-row>
										<fo:table-cell>
											<fo:block font-size="3.5mm" font-weight="bold" font-style="normal" margin-top="0.5mm">
												<xsl:value-of select="servicesDescriptor" />
											</fo:block>
										</fo:table-cell>
									</fo:table-row>
								</fo:table-body>
							</fo:table>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="services_with_routing_label_barcode">
		<fo:block-container reference-orientation="90" margin="0" width="45mm" height="45mm" overflow="visible">
			<fo:block-container reference-orientation="0" margin="0" height="6mm">
				<fo:block margin="0" padding="0">
					<xsl:text> </xsl:text>
				</fo:block>
			</fo:block-container>
			<!-- <fo:block font-size="4.75mm" font-weight="normal" text-align="left" padding="0" padding-top="3.5mm"> <xsl:value-of select="routingSourceCenterAbbr" /> </fo:block> -->
			<fo:block font-size="8mm" font-weight="bold" margin="0" padding="0" wrap-option="no-wrap">
				<xsl:value-of select="routingDestCenterAbbr" />
				<xsl:text> </xsl:text>
				<xsl:value-of select="routeNumber" />
			</fo:block>
			<fo:block font-size="1mm" font-weight="normal" padding="0">
				<xsl:call-template name="barcode">
					<xsl:with-param name="message" select="routingBarCode" />
					<xsl:with-param name="codeType" select="'routingInfo'" />
				</xsl:call-template>
			</fo:block>
		</fo:block-container>
		<fo:block-container reference-orientation="0" margin="0" width="45mm" height="9.5mm">
			<fo:block wrap-option="no-wrap" margin="0" padding="0">
				<xsl:text> </xsl:text>
			</fo:block>
		</fo:block-container>
		<fo:block-container reference-orientation="0" margin="0" width="45mm" height="3mm" overflow="visible">
			<!-- <fo:block-container reference-orientation="0" margin="0" width="45mm" height="15mm"> -->
			<fo:block font-size="2mm" wrap-option="no-wrap" margin="0" padding="0">
				<xsl:value-of select="/report/lblServices" />
			</fo:block>
			<fo:block font-size="3.2mm" font-weight="bold" font-style="normal" margin="0" padding="0" margin-top="0.2mm" padding-bottom="0.2mm">
				<xsl:value-of select="servicesDescriptor" />
			</fo:block>
		</fo:block-container>
	</xsl:template>

	<!-- ============================== -->
	<!-- Empty sticker -->
	<!-- ============================== -->

	<xsl:template name="sticker_empty">
		<xsl:choose>
			<xsl:when test="/report/demo = 'true'">
				<fo:block background-image="url('image://FOP_DEMO')" background-position="0,0" background-repeat="repeat" background-color="white" padding="3mm">
					<xsl:call-template name="_internal_sticker_empty_inner"></xsl:call-template>
				</fo:block>
			</xsl:when>
			<xsl:otherwise>
				<fo:block padding="3mm">
					<xsl:call-template name="_internal_sticker_empty_inner"></xsl:call-template>
				</fo:block>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="_internal_sticker_empty_inner">
		<fo:table width="100%">
			<fo:table-column column-width="130mm" />
			<fo:table-body>
				<fo:table-row height="75mm">
					<fo:table-cell>
						<fo:block>
							<xsl:text> </xsl:text>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="separator_horizontal">
		<fo:block width="100%" height="1px">
			<fo:table width="100%" height="1px">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell width="10mm" height="0px" padding="0" border-top-style="solid" border-top-width="thin" border-top-color="#555555">
							<fo:block width="10mm" height="0px"></fo:block>
						</fo:table-cell>
						<fo:table-cell padding="0">
							<fo:block width="1px" height="1px"></fo:block>
						</fo:table-cell>
						<fo:table-cell width="10mm" height="0px" padding="0" border-top-style="solid" border-top-width="thin" border-top-color="#555555">
							<fo:block width="10mm" height="0px"></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template name="separator_vertical">
		<fo:block width="1px" height="97mm">
			<fo:table width="1px" height="97mm">
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell width="0" height="10mm" padding="0" border-left-style="solid" border-left-width="thin" border-left-color="#555555">
							<fo:block width="0" height="0"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="71mm" padding="0">
							<fo:block width="1px" height="71mm"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="10mm" padding="0" border-left-style="solid" border-left-width="thin" border-left-color="#555555">
							<fo:block width="0" height="0"></fo:block>
						</fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell width="0" height="6mm" padding="0">
							<fo:block width="1px" height="6mm"></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<!-- ============================== -->
	<!-- Template: Forced wrap text -->
	<!-- ============================== -->

	<xsl:template name="forcedWrapText">
		<xsl:param name="data" />
		<xsl:param name="counter" select="1" />
		<xsl:choose>
			<xsl:when test="$counter &lt;= string-length($data)">
				<xsl:value-of select='concat(substring($data,$counter,1),"​&#8203;")' />
				<xsl:call-template name="forcedWrapText">
					<xsl:with-param name="data" select="$data" />
					<xsl:with-param name="counter" select="$counter+1" />
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>